////////////////////////////////////////////////////////////////////////////////
//JDEXi3:   Implements evaluation of decision alternatives based on
//          qualitative multi-attribute models produced by DEXi software
//          (http://kt.ijs.si/MarkoBohanec/dexi.html)
//
//          Authors: Marko Bohanec, Dusan Omercevic, Andrej Kogovsek
//          (http://kt.ijs.si/MarkoBohanec/jdexi.html)
//
//JDEXi3 library is free software; you can redistribute it and/or
//modify it under the terms of the GNU Lesser General Public
//License as published by the Free Software Foundation; either
//version 2.1 of the License, or (at your option) any later version.
//
//This library is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//Lesser General Public License for more details.
//
//You should have received a copy of the GNU Lesser General Public
//License along with this library; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
////////////////////////////////////////////////////////////////////////////////

package test.JDEXi;


import java.io.File;

import si.JDEXi.Attribute;
import si.JDEXi.Model;
import si.JDEXi.Rule;

/**
 * Dump all DEXi functions
 * 
 * @author Marko Bohanec
 * @version 3.0
 */
public final class DumpFunctions {

    /**
     * Main class
     * 
     * @param args
     *            Input parameters
     */
    public static void main(String[] args) {
        if (args.length != 1) {
            System.out
                    .println("Usage: java -jar DumpFunctions.jar input_DEXi_model.dxi");
            System.exit(1);
        }
        try {
            Model model = new Model(new File(args[0]));
            for(int i=0; i<model.aggregate.size(); i++) {
                Attribute a=model.aggregate.get(i);
                if(a.getRuleCount()>0) {
                    printFunction(a);
                }
            }
            } catch (Exception e) {
                System.out.println("Exception: " + e.getMessage());
            }
        }

    /**
     * Print a.function and demonstrate how to access various attribute, scale
     * and function properties.
     * 
     * @param a
     */
    public static void printFunction(Attribute a) {
        for (int j = 0; j < a.getAttributeCount(); j++) {
            Attribute x = a.getAttribute(j);
            System.out.print("\t" + x.getName());
        }
        System.out.println("\t" +a.getName());

        for (int r = 0; r < a.getRuleCount(); r++) {
            Rule rule = a.getRule(r);
            int[] args = a.indexToArgs(r);
            System.out.print(r);
            for(int z=0; z<args.length; z++) {
                System.out.print("\t"+(args[z]+1));
            }
            System.out.print("\t");
            int l=rule.getLow()+1;
            int h=rule.getHigh()+1;
            if(l==h) {
                System.out.print(l);
            } else {
                System.out.print(l+":"+h);
            }
            System.out.println("\t"+(rule.getEntered()?"+":"-"));
        }
        System.out.println();
    }
}
